@@ -438,7 +438,7 @@ void mail(Milestone *milestone, int position)
 		str[sizeof(str)-1] = 0;
 	}
 
-	strncat(str, "\nCongratulations!\n\nUptimed author,\nRob Kaper <rob@unixcode.org>\n-- \nThis message was automatically generated by Uptimed.\nUptimed e-mail notifications can be configured from the uptimed.conf file.\nFor more information visit <http://cx.capsi.com/code-uptimed.html>.\n", sizeof(str)-1);
+	strncat(str, "\nCongratulations!\n\nUptimed author,\nRob Kaper <rob@unixcode.org>\n-- \nThis message was automatically generated by Uptimed.\nUptimed e-mail notifications can be configured from the uptimed.conf file.\n", sizeof(str)-1);
 	str[sizeof(str)-1] = 0;
 	
 	snprintf(cmd, sizeof(cmd)-1, "printf \"%s\" | %s", str, sendmail);	
